# Generated by Django 4.1.2 on 2023-01-18 22:52

from django.conf import settings
from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("sites", "0002_alter_domain_unique"),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("edc_action_item", "0031_auto_20220922_2236"),
        (
            "intecomm_prn",
            "0004_rename_historicaloffschedulebaseline_historicaloffschedulecomm_and_more",
        ),
    ]

    operations = [
        migrations.RenameModel(
            old_name="HistoricalOffScheduleFollowup",
            new_name="HistoricalOffScheduleInte",
        ),
        migrations.RenameModel(
            old_name="HistoricalOnScheduleFollowup",
            new_name="HistoricalOnScheduleInte",
        ),
        migrations.RenameModel(
            old_name="OffScheduleFollowup",
            new_name="OffScheduleInte",
        ),
        migrations.RenameModel(
            old_name="OnScheduleFollowup",
            new_name="OnScheduleInte",
        ),
        migrations.AlterModelOptions(
            name="historicaloffscheduleinte",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Off-schedule Facility Integrated Care",
                "verbose_name_plural": "historical Off-schedule Facility Integrated Care",
            },
        ),
        migrations.AlterModelOptions(
            name="historicalonscheduleinte",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical On-schedule Facility Integrated Care",
                "verbose_name_plural": "historical On-schedule Facility Integrated Care",
            },
        ),
        migrations.AlterModelOptions(
            name="offscheduleinte",
            options={
                "default_permissions": ("add", "change", "delete", "view", "export", "import"),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Off-schedule Facility Integrated Care",
                "verbose_name_plural": "Off-schedule Facility Integrated Care",
            },
        ),
        migrations.AlterModelOptions(
            name="onscheduleinte",
            options={
                "default_permissions": ("add", "change", "delete", "view", "export", "import"),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "On-schedule Facility Integrated Care",
                "verbose_name_plural": "On-schedule Facility Integrated Care",
            },
        ),
        migrations.RenameIndex(
            model_name="offscheduleinte",
            new_name="intecomm_pr_id_494e36_idx",
            old_name="intecomm_pr_id_b1c9bc_idx",
        ),
        migrations.RenameIndex(
            model_name="onscheduleinte",
            new_name="intecomm_pr_id_6be831_idx",
            old_name="intecomm_pr_id_a4d7d5_idx",
        ),
    ]
