{% if change_list_href %}
<a id="patient_group_changelist_{{ screening_identifier }}"
 	title="{{ title }}"  class="btn btn-{% if patient_group.randomized %}success{% else %}default{% endif %} btn-sm" {% if perms.intecomm_screening.view_patientgroup or perms.intecomm_screening.change_patientgroup %}href="{{ change_list_href }}"{% else %}disabled{% endif %}>
  <i class="fas fa-users-between-lines fa-fw"></i>
</a>
{% endif  %}
