# Generated by Django 4.1.2 on 2023-01-23 00:06

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "intecomm_screening",
            "0015_remove_healthtalklog_unique_health_facility_report_date_and_more",
        ),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalpatientlog",
            name="group_identifier",
            field=models.CharField(
                blank=True,
                help_text="Auto populated when group is randimized",
                max_length=25,
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="patientlog",
            name="group_identifier",
            field=models.CharField(
                blank=True,
                help_text="Auto populated when group is randimized",
                max_length=25,
                null=True,
            ),
        ),
    ]
