# Generated by Django 4.1.2 on 2022-12-06 23:04

from django.conf import settings
from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("sites", "0002_alter_domain_unique"),
        ("edc_action_item", "0031_auto_20220922_2236"),
        ("intecomm_prn", "0003_historicalprotocolincident_reasons_withdrawn_and_more"),
    ]

    operations = [
        migrations.RenameModel(
            old_name="HistoricalOffScheduleBaseline",
            new_name="HistoricalOffScheduleComm",
        ),
        migrations.RenameModel(
            old_name="HistoricalOnScheduleBaseline",
            new_name="HistoricalOnScheduleComm",
        ),
        migrations.RenameModel(
            old_name="OffScheduleBaseline",
            new_name="OffScheduleComm",
        ),
        migrations.RenameModel(
            old_name="OnScheduleBaseline",
            new_name="OnScheduleComm",
        ),
        migrations.AlterModelOptions(
            name="historicaloffschedulecomm",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Off-schedule Community Integrated Care",
                "verbose_name_plural": "historical Off-schedule Community Integrated Care",
            },
        ),
        migrations.AlterModelOptions(
            name="historicalonschedulecomm",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical On-schedule Community Integrated Care",
                "verbose_name_plural": "historical On-schedule Community Integrated Care",
            },
        ),
        migrations.AlterModelOptions(
            name="offschedulecomm",
            options={
                "default_permissions": ("add", "change", "delete", "view", "export", "import"),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Off-schedule Community Integrated Care",
                "verbose_name_plural": "Off-schedule Community Integrated Care",
            },
        ),
        migrations.AlterModelOptions(
            name="onschedulecomm",
            options={
                "default_permissions": ("add", "change", "delete", "view", "export", "import"),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "On-schedule Community Integrated Care",
                "verbose_name_plural": "On-schedule Community Integrated Care",
            },
        ),
        migrations.RenameIndex(
            model_name="offschedulecomm",
            new_name="intecomm_pr_id_3f0fba_idx",
            old_name="intecomm_pr_id_829ea5_idx",
        ),
        migrations.RenameIndex(
            model_name="onschedulecomm",
            new_name="intecomm_pr_id_d4e5db_idx",
            old_name="intecomm_pr_id_52a218_idx",
        ),
    ]
