care_delivery_fieldset_tuple = (
    "Care",
    {"fields": ("care_delivery", "care_delivery_other")},
)

treatment_pay_methods_fieldset_tuple = (
    "Other",
    {
        "fields": (
            "health_insurance",
            "health_insurance_monthly_pay",
            "patient_club",
            "patient_club_monthly_pay",
        )
    },
)
