# Generated by Django 4.1.2 on 2022-11-21 21:02

from django.db import migrations
import django_crypto_fields.fields.encrypted_char_field


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_screening", "0003_site_remove_historicalpatientlog_patient_group_and_more"),
    ]

    operations = [
        migrations.RenameField(
            model_name="historicalpatientlog",
            old_name="name",
            new_name="legal_name",
        ),
        migrations.RenameField(
            model_name="patientlog",
            old_name="name",
            new_name="legal_name",
        ),
        migrations.AddField(
            model_name="historicalpatientlog",
            name="familiar_name",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True,
                help_text=" (Encryption: RSA local)",
                max_length=71,
                verbose_name="How should we refer to you? (if we speak to you)",
            ),
        ),
        migrations.AddField(
            model_name="patientlog",
            name="familiar_name",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True,
                help_text=" (Encryption: RSA local)",
                max_length=71,
                verbose_name="How should we refer to you? (if we speak to you)",
            ),
        ),
    ]
